{ Marco Cantu' (author of Master Delphi x and Delphi Developers Handbook has   }
{ released an excellent run-time object inspector tool as freeware.  It can be }
{ found in the Delphi Developers Handbook (highly recommended) and on his web  }
{ site at http://www.marcocantu.com.  If you have this installed, you can      }
{ enable the following define (remove the period) to use it in the demo.       }
{ It is for Delphi 3 only, but I think he has a beta for Delphi 2.             }
{.$DEFINE DFS_RUN_TIME_DEBUGGER}

unit DemoMain;

interface

uses
  WinTypes, WinProcs, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  DdhObjDb,
  {$ENDIF}
  Dialogs, VersInfo, StdCtrls, Grids, ComCtrls;

type
  TForm1 = class(TForm)
    Info: TMemo;
    VersionInfoResource1: TVersionInfoResource;
    Product: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label1: TLabel;
    ListView1: TListView;
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}



// Note that VER100 is intentionally left out because it is part of the project
// options.

{$IFDEF VER90}
  {$R VERTEST.R32}
{$ELSE}
  {$IFDEF VER80}
    {$R VERTEST.R16}
  {$ENDIF}
{$ENDIF}


procedure TForm1.FormCreate(Sender: TObject);
const
  FLAG_STRING: array[TFixedFileInfoFlag] of string = (
      'Debug', 'Info Inferred', 'Patched', 'Pre-Release', 'Private', 'Special'
    );
  OS_STRING: array[TVersionOperatingSystemFlag] of string = (
      'Unknown', 'DOS', 'OS2 16-bit', 'OS2 32-bit', 'Windows NT', 'Windows 16-bit',
      'Presentation Manager 16-bit', 'Presentation Manager 32-bit', 'Windows 32-bit'
    );
  FILETYPE_STRING: array[TVersionFileType] of string = (
      'Unknown', 'Application', 'DLL', 'Driver', 'Font', 'VXD', 'StaticLib'
    );
var
  AFlag: TFixedFileInfoFlag;
  OSFlag: TVersionOperatingSystemFlag;
  TempStr: string;
begin
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  TDdhObjectDebugger.Create(Self);
  {$ENDIF}
  with VersionInfoResource1 do
  begin
    Info.Lines.Add('CompanyName = ' + CompanyName);
    Info.Lines.Add('FileVersion = ' + FileVersion.AsString);
    Info.Lines.Add('InternalName = ' + InternalName);
    Info.Lines.Add('LegalCopyright = ' + LegalCopyright);
    Info.Lines.Add('LegalTrademarks = ' + LegalTrademarks);
    Info.Lines.Add('OriginalFilename = ' + OriginalFilename);
    Info.Lines.Add('ProductName = ' + ProductName);
    Info.Lines.Add('ProductVersion = ' + ProductVersion.AsString);
    Info.Lines.Add('Comments = ' + Comments);
    Info.Lines.Add('Test = ' + UserResource['Test']);

    Info.Lines.Add('');
    Info.Lines.Add('Fixed Info:');
    Info.Lines.Add('Signature = ' + IntToStr(FixedInfo.Signature) + ' ($' +
       IntToHex(FixedInfo.Signature, 16) + ')');
    Info.Lines.Add('StructureVersion = ' + IntToStr(FixedInfo.StructureVersion) + ' ($' +
       IntToHex(FixedInfo.StructureVersion, 16) + ')');
    Info.Lines.Add('FileVersionMS = ' + IntToStr(FixedInfo.FileVersionMS) + ' ($' +
       IntToHex(FixedInfo.FileVersionMS, 16) + ')');
    Info.Lines.Add('FileVersionLS = ' + IntToStr(FixedInfo.FileVersionLS) + ' ($' +
       IntToHex(FixedInfo.FileVersionLS, 16) + ')');
    Info.Lines.Add('ProductVersionMS = ' + IntToStr(FixedInfo.ProductVersionMS) + ' ($' +
       IntToHex(FixedInfo.ProductVersionMS, 16) + ')');
    Info.Lines.Add('ProductVersionLS = ' + IntToStr(FixedInfo.ProductVersionLS) + ' ($' +
       IntToHex(FixedInfo.ProductVersionLS, 16) + ')');

    TempStr := 'Build Flags = ';
    for AFlag := Low(TFixedFileInfoFlag) to High(TFixedFileInfoFlag) do
    begin
      if AFlag in FixedInfo.Flags then
        TempStr := TempStr + ' ' + FLAG_STRING[AFlag];
    end;
    Info.Lines.Add(TempStr);

    TempStr := 'Operating System = ';
    for OSFlag := Low(TVersionOperatingSystemFlag) to High(TVersionOperatingSystemFlag) do
    begin
      if OSFlag in FixedInfo.FileOperatingSystem then
        TempStr := TempStr + ' ' + OS_STRING[OSFlag];
    end;
    Info.Lines.Add(TempStr);

    Info.Lines.Add('File Type = ' + FILETYPE_STRING[FixedInfo.FileType]);
    Info.Lines.Add('File SubType = ' + IntToStr(FixedInfo.FileSubType) + ' ($' +
       IntToHex(FixedInfo.FileSubType, 16) + ')');
    Info.Lines.Add('Creation Date = ' + DateTimeToStr(FixedInfo.CreationDate));
  end;
end;

end.
